﻿using System;

namespace BBIWARG.Input.InputProviding
{
    /// <summary>
    /// Encapsulates the arguments of the event that a new frame is available.
    /// </summary>
    public class NewFrameEventArgs : EventArgs
    {
        /// <summary>
        /// the id of the frame
        /// </summary>
        public int FrameID { get; private set; }

        /// <summary>
        /// the height of all images in the frame
        /// </summary>
        public int Height { get; private set; }

        /// <summary>
        /// pointer to the raw confidence data for the frame
        /// </summary>
        public IntPtr RawConfidenceData { get; private set; }

        /// <summary>
        /// pointer to the raw depth data for the frame
        /// </summary>
        public IntPtr RawDepthData { get; private set; }

        /// <summary>
        /// the with of all images in the frame
        /// </summary>
        public int Width { get; private set; }

        /// <summary>
        /// Constructs a NewFrameEventArgs.
        /// </summary>
        /// <param name="frameID">frame id</param>
        /// <param name="width">width of all images</param>
        /// <param name="height">height of all images</param>
        /// <param name="rawDepthData">pointer to raw depth data</param>
        /// <param name="rawConfidenceData">pointer to raw confidence data</param>
        public NewFrameEventArgs(int frameID, int width, int height, IntPtr rawDepthData, IntPtr rawConfidenceData)
        {
            FrameID = frameID;
            Width = width;
            Height = height;
            RawDepthData = rawDepthData;
            RawConfidenceData = rawConfidenceData;
        }
    }
}